<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Închide (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Restrînge</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Extinde</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Revocare alertă</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln cuvînt</numerusform>
            <numerusform>%Ln cuvinte</numerusform>
            <numerusform>%Ln cuvinte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minute</numerusform>
            <numerusform>%Ln minute</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% din %Ln minut</numerusform>
            <numerusform>%L1% din %Ln minute</numerusform>
            <numerusform>%L1% din %Ln minute</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% of %Ln cuvînt</numerusform>
            <numerusform>%L1% of %Ln cuvinte</numerusform>
            <numerusform>%L1% of %Ln cuvinte</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progres zilnic</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Ce mai lungă perioadă</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Perioada curentă</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Indisponibil</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n zi(le)</numerusform>
            <numerusform>%n zi</numerusform>
            <numerusform>%n zile</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% din obiectiv zilnic</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Setare limbă</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Fără titlu %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Doar-citire)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nu se poate salva &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Salvează fişierul ca</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nu se poate suprascrie&apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Redenumire fişier</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nu se poate redenumi &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Reîncarcă fişier?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Reîncarcă fişierul &apos;%1&apos; de pe disc?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Toate modificările nesalvate vor fi pierdute.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Reîncarcă</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>FărăTitlu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Salvînd ca text simplu se vor pierde toate formatările. Renunţaţi la formatare?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Fişierul a fost modificat</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Fişierul &apos;%1&apos; a fost modificat de un alt program.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Doriţi să reîncărcaţi fişierul?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Reîncarcă</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoră</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Fişier şters</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Fişierul %1 a fost şters de un alt program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Doriţi să salvaţi sau  închideţi fişierul?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nu se poate deschide arhiva.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Caută:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Înlocuieşte cu:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignoră minuscule/majuscule</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Doar cuvinte întregi</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expresii regulate</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Caută în sus</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Caută în jos</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Caută</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Înlocuieşte</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Înlocuieşte to&amp;ate</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Căutare</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Înlocuire</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Înlocuire %n o dată?</numerusform>
            <numerusform>Înlocuire %n ori?</numerusform>
            <numerusform>Înlocuire %n ori?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Fraza nu a fost găsită.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Text OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Text îmbogăţit</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Text simplu</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Toate fişierele</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Toate fişierele suportate</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Adaugă</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Verificare ortografică...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nu s-au găsit sugestii)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Deschide imagine</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagini</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nu se poate deschide arhiva.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferinţe</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistici</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Bară de intrumente</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Verificare ortografică</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Selectaţi dicţionarul</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nu se poate deschide arhiva</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arhiva nu conţine un dicţionar utilizabil.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scurtături</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Una sau mai multe scurtături sînt în conflict. Doriţi să continuaţi?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Dicţionarul &quot;%1&quot; deja există. Doriţi să-l înlocuiţi?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Obiectiv zilnic</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niciunul</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minute:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Cuvinte:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Editare</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Centrează vertical întotdeauna</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Cursor block de inserare</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Netezire font-uri</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Sunete maşină de scris</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Ghilimele inteligente:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duble</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simple</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scene</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Divizor:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Salvare</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Amintire poziţie cursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Contor cuvinte</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Contor pagini</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Contor paragrafe</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Contor caractere</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caractere:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragrafe:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritm contorizare cuvinte</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Resetare progres zilnic pentru astăzi la zero?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Scrie marker ordine octeţi în fişierele de text simplu</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Format iniţial:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Resetare astăzi</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Istoric</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Amintire istoric</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Arată perioade</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progres minim pentru perioade:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detectare limite cuvinte</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Împarte numărul de caractere cu şase</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Contorizează fiecare literă ca şi cuvînt</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritm contorizare pagini</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Doar iconuri</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Doar text</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Text lîngă iconuri</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Text sub iconuri</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Poziţie text</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acţiuni</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Mută în sus</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Mută în jos</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Adaugă separator</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comandă</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Scurtătură</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acţiune</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Verificare ortografică în timpul tastării</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorare cuvinte cu MAJUSCULE</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorare cuvinte care conţin cifre</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Limbă</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adăugare</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Înlăturare</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Dicţionar personal</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Înlăturaţi dicţionarul curent?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interfaţă utilizator</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Arată întotdeauna bările de defilare</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Arată întotdeauna bara de sus</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Arată întotdeauna bara de jos</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Fişier RTF nesuportat.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>S-a ajuns pe neaşteptate la sfîrşitul fişierului.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Săgeată în jos</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Mută scene în sus</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Săgeată în sus</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Comutare listă scene</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Arată listă scene (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Ascunde listă scene (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtru</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Mută scene în jos</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Redimensionare listă scene</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Iniţial</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestionare sesiuni</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;esiuni</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Redenumire</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Comută la</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Sesiune nouă</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplică sesiune</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Redenumire sesiune</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Şterge sesiunea selectată?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nume sesiune:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Numele solicitat al sesiunii este deja în uz.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nou...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>Gestionare...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Curăţă</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Resetează la valorile implicte</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Scurtătură:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Înlocuire ghilimele...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vă rugăm aşteptaţi</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Verificare ortografică</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adaugă</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignoră</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnoră toate</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Modifică</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Modifică &amp;toate</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nu este în dicţionar:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Modifică în:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Verificare ortografie...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Vă rugăm aşteptaţi</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Continuă verificarea de la începutul fişierului?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Verificare ortografică completă.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simboluri</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Simbolurile folosite recent</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Toate simbolurile</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalii</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nume:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserează</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocuri</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Script-uri</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>FărăTitlu %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nume:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Fără imagine</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Placat</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrat</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Întins</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Redimensionat</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Mărit</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacitate:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Poziţie:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Lăţime:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Text fundal colţuri rotunjite </translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Rază:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Estompare text fundal</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Umbră text fundal</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Offset vertical:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margini</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Fereastră:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Pagină:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Indentare prima linie</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Deasupra:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Sub:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Înlătură</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Editare temă</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fundal fereastră</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Culoare:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imagine:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixeli</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Stînga</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Text fundal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreapta</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Greşit:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Spaţiere rînd</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simplă</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 linii</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Două rînduri</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporţional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Înălţime:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Spaţiere paragraf</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Lăţime tab:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Temă nouă</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Teme</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Iniţial</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Albatru gentil</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Vechea şcoală</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Vise spaţiale</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Birou de scris</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicat</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizată</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Ştergeţi tema &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Teme (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importare temă</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportare temă</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Cer morocănos</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Încîntare</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Jocuri spion</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Linişte</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Şterge cronometru?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Cuvinte:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pagini:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragrafe:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caractere:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Setare întîrzîiere</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Setare timp</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Întîrzîiere:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Timp:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarmă</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Notă:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nu există cronometre care rulează</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Cronometre</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recent</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Anulare cronometru editare?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Încărcare teme</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Încărcare sunete</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>FărăTitlu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Deschide fişier</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Despre FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un procesor simplu de text pe tot ecranul</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Foloseşte iconuri din tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Folosit sub licenţă &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caractere: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Pagini: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragrafe: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Cuvinte: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Deschidere %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Fără titlu %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Listă toate documentele</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Comutare la următorul document</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Comutare la documentul precedent</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Comutare la primul document</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Comutare la ultimul document</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Comutare la document %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Încărcare setări</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Cache-ul de urgenţă nu poate fi scris.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avertisment</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter nu a fost oprit corect.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Restaurare din memoria cache de urgenţă?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Unele fişiere nu au putut fi deschise.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Unele fişiere au fost deschise în mod doar-citire.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; este mai nou decît copia din cache.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Suprascrie noul fişier?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Salvaţi modificările?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Salvează modificările în fişierul &apos;%1&apos; înainte de închidere?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Modificările dvs. vor fi pierdure dacă nu le salvaţi.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nu se pot încărca sunetele maşină de scris.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fişier</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Deschide...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Reîncarcă</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvare</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Salvare c&amp;a...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Redenumire...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Sa&amp;lvează tot</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestionare sesiuni</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Sesiune nouă</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Imprimare...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editare</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Reface</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Taie</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiază</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Lipeşte</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Lipire neformatat</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Selectează &amp;tot</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Selectare &amp;scenă</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmatare</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Îngroşat</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Italic</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>S&amp;ubliniat</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Tăiat</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Exponent</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Indice</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Aliniere la &amp;stînga</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Aliniere la &amp;centru</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Aliniere la &amp;dreapta</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Aliniere stînga-dreapta</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Mărire alineat</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Micşorare alineat</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Bloc stînga-dreapta</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Bloc dreapta-stînga</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Unelte</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Caută...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Caută &amp;următorul</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Caută &amp;precedent</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Înlocuire...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Ghilimele inteligente</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Actualizare &amp;document</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Actualizare &amp;selecţie</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Ortografie...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Setare &amp;limbă...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Cronometre...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;imboluri...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Progres zilnic</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Arată bară de unelte</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Arată iconuri &amp;meniu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Text f&amp;ocalizat</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Tot ecranul</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimizare</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Teme...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferinţe...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Focaliuzare oprită</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focalizare o linie</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focalizare trei linii</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragraf</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focalizare paragraf</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Unele fişiere au fost nesuportate şi nu au putut fi deschide.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Oprit</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>O &amp;linie</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Trei linii</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Setări pa&amp;gină...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Rubrică</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Rubrică &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Rubrică &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Rubrică &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Rubrică &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Rubrică &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Rubrică &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Actualizare ghilimele inteligente în document</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Actualizare ghilimele inteligente în selecţie</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Fișiere de deschis în sesiunea curentă</translation>
    </message>
</context>
</TS>
